@@ -1,12 +1,13 @@
 #'Build an averaged error correction model
 #'
-#'Builds multiple ECM models on subsets of the data and averages them.
+#'Builds multiple ECM models on subsets of the data and averages them. See the lmave function for more details
+#'on the methodology and use cases for this approach. 
 #'@param y The target variable
 #'@param xeq The variables to be used in the equilibrium term of the error correction model
 #'@param xtr The variables to be used in the transient term of the error correction model
 #'@param includeIntercept Boolean whether the y-intercept should be included
 #'@param k The number of models or data partitions desired
-#'@param method Whether to split data by folds ("fold") or by bootstrapping ("boot")
+#'@param method Whether to split data by folds ("fold"), nested folds ("nestedfold"), or bootstrapping ("boot")
 #'@param seed Seed for reproducibility (only needed if method is "boot")
 #'@param weights Optional vector of weights to be passed to the fitting process
 #'@param ... Additional arguments to be passed to the 'lm' function (careful in that these may need to be modified for ecm or may not be appropriate!)
@@ -48,13 +49,24 @@ ecmave <- function (y, xeq, xtr, includeIntercept = TRUE, k, method = 'boot', se
   
   xeqnames <- names(xeq)
   xeqnames <- paste0(xeqnames, "Lag1")
-  ifelse(ncol(xeq) > 1, xeq <- rbind(rep(NA, ncol(xeq)), xeq[1:(nrow(xeq) - 1), ]), xeq <- data.frame(c(NA, xeq[1:(nrow(xeq) - 1), ])))
+  if(ncol(xeq) > 1) {
+    xeq <- rbind(rep(NA, ncol(xeq)), xeq[1:(nrow(xeq) - 1), ])
+  } else {
+    xeq <- data.frame(c(NA, xeq[1:(nrow(xeq) - 1), ]))
+  }
   
   xtrnames <- names(xtr)
   xtrnames <- paste0("delta", xtrnames)
   xtr <- data.frame(apply(xtr, 2, diff, 1))
   
+  if (class(y)=='data.frame'){
+    if (ncol(y) > 1){
+      warning("You have more than one column in y, only the first will be used")
+    }
+    y <- y[,1]
+  }
   yLag1 <- y[1:(length(y) - 1)]
+  
   x <- cbind(xtr, xeq[complete.cases(xeq), ])
   x <- cbind(x, yLag1)
   names(x) <- c(xtrnames, xeqnames, "yLag1")
